@@ -12,8 +12,7 @@
 #include "declarativedevice.h"
 #include "device.h"
 #include "initmanagerjob.h"
-
-static int adaptersCountFunction(QQmlListProperty<DeclarativeAdapter> *property)
+static qsizetype adaptersCountFunction(QQmlListProperty<DeclarativeAdapter> *property)
 {
     Q_ASSERT(qobject_cast<DeclarativeManager *>(property->object));
     DeclarativeManager *manager = static_cast<DeclarativeManager *>(property->object);
@@ -21,7 +20,7 @@ static int adaptersCountFunction(QQmlListProperty<DeclarativeAdapter> *property)
     return manager->m_adapters.count();
 }
 
-static DeclarativeAdapter *adaptersAtFunction(QQmlListProperty<DeclarativeAdapter> *property, int index)
+static DeclarativeAdapter *adaptersAtFunction(QQmlListProperty<DeclarativeAdapter> *property, qsizetype index)
 {
     Q_ASSERT(qobject_cast<DeclarativeManager *>(property->object));
     DeclarativeManager *manager = static_cast<DeclarativeManager *>(property->object);
@@ -29,7 +28,7 @@ static DeclarativeAdapter *adaptersAtFunction(QQmlListProperty<DeclarativeAdapte
     return manager->m_adapters.values().at(index);
 }
 
-static int devicesCountFunction(QQmlListProperty<DeclarativeDevice> *property)
+static qsizetype devicesCountFunction(QQmlListProperty<DeclarativeDevice> *property)
 {
     Q_ASSERT(qobject_cast<DeclarativeManager *>(property->object));
     DeclarativeManager *manager = static_cast<DeclarativeManager *>(property->object);
@@ -37,7 +36,7 @@ static int devicesCountFunction(QQmlListProperty<DeclarativeDevice> *property)
     return manager->m_devices.count();
 }
 
-static DeclarativeDevice *devicesAtFunction(QQmlListProperty<DeclarativeDevice> *property, int index)
+static DeclarativeDevice *devicesAtFunction(QQmlListProperty<DeclarativeDevice> *property, qsizetype index)
 {
     Q_ASSERT(qobject_cast<DeclarativeManager *>(property->object));
     DeclarativeManager *manager = static_cast<DeclarativeManager *>(property->object);
