@@ -11,12 +11,14 @@
 
 #include <QObject>
 
-#include "types.h"
 #include "bluezqt_export.h"
+#include "rfkill.h"
+#include "types.h"
+
+#include <memory>
 
 namespace BluezQt
 {
-
 class Device;
 class Adapter;
 class Agent;
@@ -85,6 +87,7 @@ class BLUEZQT_EXPORT Manager : public QObject
     Q_PROPERTY(AdapterPtr usableAdapter READ usableAdapter NOTIFY usableAdapterChanged)
     Q_PROPERTY(QList<AdapterPtr> adapters READ adapters)
     Q_PROPERTY(QList<DevicePtr> devices READ devices)
+    Q_PROPERTY(Rfkill *rfkill READ rfkill CONSTANT)
 
 public:
     /**
@@ -97,7 +100,7 @@ public:
     /**
      * Destroys a Manager object.
      */
-    ~Manager();
+    ~Manager() override;
 
     /**
      * Creates a new init job.
@@ -148,15 +151,13 @@ public:
     /**
      * Sets a Bluetooth blocked state.
      *
-     * This may fail either due to insufficent permissions or
+     * This may fail either due to insufficient permissions or
      * because rfkill state is HARD_BLOCKED. In that case,
      * this function returns false.
      *
      * @note This requires write access to /dev/rfkill.
-     *
-     * @return true if unblocking rfkill devices succeeded
      */
-    bool setBluetoothBlocked(bool blocked);
+    void setBluetoothBlocked(bool blocked);
 
     /**
      * Returns a usable adapter.
@@ -283,16 +284,7 @@ public:
      */
     PendingCall *unregisterProfile(Profile *profile);
 
-#if BLUEZQT_ENABLE_DEPRECATED_SINCE(5, 57)
-    /**
-     * Returns the media interface.
-     *
-     * @return media
-     * @deprecated since 5.57, use Adapter::media() instead.
-     */
-    BLUEZQT_DEPRECATED_VERSION(5, 57, "Use Adapter::media()")
-    MediaPtr media() const;
-#endif
+    Rfkill *rfkill() const;
 
 Q_SIGNALS:
     /**
@@ -351,7 +343,7 @@ Q_SIGNALS:
     void allAdaptersRemoved();
 
 private:
-    class ManagerPrivate *const d;
+    std::unique_ptr<class ManagerPrivate> const d;
 
     friend class ManagerPrivate;
     friend class InitManagerJobPrivate;
